
package com.rc.retroweaver.runtime;

/**
 * A replacement for the new boxing functions which were added
 * for autoboxing in 1.5.
 *
 * @author Toby Reyelts
 *
 */
public class Autobox {

  // Small lookup table for Byte objects
  private static Byte[] bytes = new Byte[ 256 ];

  static {
    for ( int i = 0; i < 256; ++i ) {
      bytes[ i ] = new Byte( ( byte )( i - 128 ) );
    }
  }

  public static Boolean valueOf( boolean b ) {
    return b ? Boolean.TRUE : Boolean.FALSE;
  }

  /**
   * This method is a little faster than the current implementation of 
   * Byte.valueOf() because it uses a lookup table.
   *
   */
  public static Byte valueOf( byte b ) {
    return bytes[ b + 128 ];
  }

  public static Character valueOf( char c ) {
    return new Character( c );
  }

  public static Short valueOf( short s ) {
    return new Short( s );
  }

  public static Integer valueOf( int i ) {
    return new Integer( i );
  }

  public static Long valueOf( long l ) {
    return new Long( l );
  }

  public static Float valueOf( float f ) {
    return new Float( f );
  }

  public static Double valueOf( double d ) {
    return new Double( d );
  }
}

